@@ -1,6 +1,8 @@
 .onLoad <- function(libname, pkgname) {
 	if (!.jniInitialized) {
-		.jinit(parameters="-Xrs")
+		.jinit(parameters=c("-Xrs", "-Xss1m"))
+	} else {
+    warning("JVM was already initialized with unknown memory settings.")
 	}
 	.jpackage(pkgname)	
 	.jpackage("JavaGD")
@@ -13,9 +15,18 @@
 	loadJars(jars)
 	
 	# The following few lines are based on the code of the rJava .jpackage function
+  # TODO This is work in progress. What about MacOS?
+	if (length(grep("64-bit", sessionInfo()$platform))>0) {
+	  classes <- system.file("jri/x64", package = "rJava", lib.loc = NULL)
+	} else {
+	  classes <- system.file("jri/i386", package = "rJava", lib.loc = NULL)
+	}
+	if (nzchar(classes)) {
+	  .jaddClassPath(classes)
+	}
 	classes <- system.file("jri", package = "rJava", lib.loc = NULL)
 	if (nzchar(classes)) {
-		.jaddClassPath(classes)
+		#.jaddClassPath(classes)
 		jars <- grep(".*\\.jar", list.files(classes, full.names = TRUE), TRUE, value = TRUE)
 		if (length(jars)) { 
 			.jaddClassPath(jars)
@@ -25,8 +36,8 @@
 	rJavaVersion <- utils::sessionInfo()$otherPkgs$rJava$Version
 	
 	# If we have a rJava version < 0.8-3 load JRIEngine.jar and REngine.jar
-    if (!is.null(rJavaVersion)) {
-    	if (rJavaVersion < "0.8-3") {
+  if (!is.null(rJavaVersion)) {
+  	if (rJavaVersion < "0.8-3") {
 			classes <- system.file("R28", package = "CommonJavaJars", lib.loc = NULL)
 			if (nzchar(classes)) {
 				.jaddClassPath(classes)
@@ -35,19 +46,20 @@
 					.jaddClassPath(jars)
 				}		
 			}
-		}
+		}	
 		# If we have a rJava version > 0.9-3 load JRIEngine.jar and REngine.jar
-	    if (rJavaVersion > "0.9-3") {
-			classes <- system.file("JRI", package = "CommonJavaJars", lib.loc = NULL)
-			if (nzchar(classes)) {
-				.jaddClassPath(classes)
-				jars <- grep(".*\\.jar", list.files(classes, full.names = TRUE), TRUE, value = TRUE)
-				if (length(jars)) { 
-					.jaddClassPath(jars)
-				}		
-			}
+		if (rJavaVersion > "0.9-3") {
+		  classes <- system.file("JRI", package = "CommonJavaJars", lib.loc = NULL)
+		  if (nzchar(classes)) {
+		    .jaddClassPath(classes)
+		    jars <- grep(".*\\.jar", list.files(classes, full.names = TRUE), TRUE, value = TRUE)
+		    if (length(jars)) { 
+		      .jaddClassPath(jars)
+		    }		
+		  }
 		}
-	}
+	}  
+
 	
 	## We supply our own JavaGD class
 	Sys.setenv("JAVAGD_CLASS_NAME"="org/mutoss/gui/JavaGD")  
@@ -67,6 +79,12 @@
 	#require("graph")
 	#options(warn=0)
 	
+	#TODO How to test for 64-bit R? In the moment I use: .Machine$sizeof.pointer != 8
+	#if (length(grep("64-bit", sessionInfo()$platform))==0 || .Machine$sizeof.pointer != 8) {
+	#	rversion <- c(sessionInfo()$R.version$major, unlist(strsplit(sessionInfo()$R.version$minor, "\\.")))
+	#	if ((rversion[1]==2&&rversion[2]==15&&rversion[3]>=2)|| rversion[1]>=3) warning("WARNING: You may experience crashes due to memory problems.\nPlease try to either i) use an old R<=2.15.2 or ii) R with 64-bit on Windows 64.\nWe are working on this problem.\nIf you experience no crashes everything is fine.")
+	#}
+	
 	# packageStartupMessage or cat for furter information (package incompatibilities / updates)
 }  
 
